@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function
-
-from pytest import main
+import pytest  # noqa
 
 from basicco.mangling import mangle, unmangle, extract
 
@@ -33,4 +31,4 @@ def test_extract():
 
 
 if __name__ == "__main__":
-    main()
+    pytest.main()
